'''
Subpackage myimg.utils
----------------------

The subpackage contains various utilities in for package myutils:
    
* myimg.utils.label = draw a label in the upper left corner of an image
* myimg.utils.scalebar = draw a scalebar in a micrograph (or diffractogram)
* myimg.utils.montage = create multi-image (montage) from several images
'''
